@@ -3,6 +3,7 @@ use utf8;
 use strict;
 use warnings FATAL => 'all';
 
+use Class::MOP 0.94;
 use Muldis::Rosetta::Interface 0.014000;
 
 ###########################################################################
@@ -12,10 +13,12 @@ use Muldis::Rosetta::Interface 0.014000;
     our $VERSION = '0.014000';
     $VERSION = eval $VERSION;
 
-    use namespace::autoclean 0.08;
+    use namespace::autoclean 0.09;
+
+    use Try::Tiny 0.02;
 
     use Test::More 0.92;
-    use Test::Moose 0.89;
+    use Test::Moose 0.92;
 
 ###########################################################################
 
@@ -24,25 +27,57 @@ sub main {
     my ($engine_name, $process_config)
         = @{$args}{'engine_name', 'process_config'};
 
-    print "#### Muldis::Rosetta::Validator"
-        . " starting test of $engine_name ####\n";
+    if (!defined $engine_name or $engine_name eq q{}) {
+        BAIL_OUT( q{Muldis::Rosetta::Validator: Bad :$engine_name arg;}
+            . q{ it is undefined or it is the empty string.} );
+        return;
+    }
+
+    diag( "Muldis::Rosetta::Validator starting test of $engine_name." );
+
+    # Load Perl module implementing the Muldis Rosetta Engine.
+    my $is_bailing_now = 0;
+    try {
+        Class::MOP::load_class( $engine_name );
+    }
+    catch {
+        BAIL_OUT( q{Muldis::Rosetta::Validator: Could not load}
+            . qq{ Muldis Rosetta Engine module '$engine_name': $_.} );
+        $is_bailing_now = 1;
+    };
+    return
+        if $is_bailing_now;
+    if (!Class::MOP::is_class_loaded( $engine_name )) {
+        BAIL_OUT( q{Muldis::Rosetta::Validator:}
+            . q{ Could not load Muldis Rosetta Engine module}
+            . qq{ '$engine_name': while that file did compile without}
+            . q{ errors, it did not declare the same-named module.} );
+        return;
+    }
+    if (!$engine_name->can( 'new_machine' )) {
+        BAIL_OUT( q{Muldis::Rosetta::Validator:}
+            . q{ The Muldis Rosetta Engine module '$engine_name' does not}
+            . q{ provide the new_machine() constructor function.} );
+        return;
+    }
+    diag( "$engine_name loads and declares new_machine() constructor." );
+    pass( 'Engine module loads and declares new_machine() constructor' );
 
     # Instantiate a Muldis Rosetta DBMS / virtual machine.
-    my $machine = Muldis::Rosetta::Interface::new_machine({
-        'engine_name' => $engine_name,
-    });
+    my $machine = &{$engine_name->can( 'new_machine' )}();
+    pass( 'no death from instantiating new/singleton virtual machine' );
     does_ok( $machine, 'Muldis::Rosetta::Interface::Machine' );
     my $process = $machine->new_process({
         'process_config' => $process_config,
     });
+    pass( 'no death from instantiating new VM process' );
     does_ok( $process, 'Muldis::Rosetta::Interface::Process' );
     $process->update_hd_command_lang({ 'lang' => [ 'Muldis_D',
-        'http://muldis.com', '0.85.0', 'HDMD_Perl5_STD' ] });
+        'http://muldis.com', '0.99.0', 'HDMD_Perl5_STD' ] });
 
     _scenario_foods_suppliers_shipments_v1( $process );
 
-    print "#### Muldis::Rosetta::Validator"
-        . " finished test of $engine_name ####\n";
+    diag( "Muldis::Rosetta::Validator finished test of $engine_name." );
 
     done_testing();
 
@@ -129,9 +164,9 @@ sub _scenario_foods_suppliers_shipments_v1 {
     #     [ 'Beckers'  , 'England' ],
     # ] ] ],
 
-    print "# debug: orange food suppliers found:\n";
-#    print "# " . $matched_suppl_as_perl->as_perl() . "\n";
-    print "#  TODO, as_perl()\n";
+    diag( 'debug: orange food suppliers found:' );
+#    diag( $matched_suppl_as_perl->as_perl() );
+    diag( ' TODO, as_perl()' );
 
     return;
 }
@@ -157,7 +192,7 @@ A common comprehensive test suite to run against all Engines
 
 =head1 VERSION
 
-This document describes Muldis::Rosetta::Validator version 0.14.0 for Perl
+This document describes Muldis::Rosetta::Validator version 0.15.0 for Perl
 5.
 
 =head1 SYNOPSIS
@@ -246,12 +281,13 @@ installation by users of earlier Perl versions:
 L<Test::More-ver(0.92..*)|Test::More>.
 
 It also requires these Perl 5 packages that are on CPAN:
-L<namespace::autoclean-ver(0.08..*)|namespace::autoclean>,
-L<Test::Moose-ver(0.89..*)|Test::Moose>.
+L<namespace::autoclean-ver(0.09..*)|namespace::autoclean>,
+L<Try::Tiny-ver(0.02..*)|Try::Tiny>, L<Class::MOP-ver(0.94..*)|Class::MOP>,
+L<Test::Moose-ver(0.92..*)|Test::Moose>.
 
 It also requires these Perl 5 packages that are in the current
 distribution:
-L<Muldis::Rosetta::Interface-ver(0.14.0..*)|Muldis::Rosetta::Interface>.
+L<Muldis::Rosetta::Interface-ver(0.15.0..*)|Muldis::Rosetta::Interface>.
 
 =head1 INCOMPATIBILITIES
 
@@ -269,7 +305,7 @@ I<This documentation is pending.>
 
 =head1 AUTHOR
 
-Darren Duncan (C<perl@DarrenDuncan.net>)
+Darren Duncan (C<darren@DarrenDuncan.net>)
 
 =head1 LICENSE AND COPYRIGHT
 
